@@ -17,18 +17,16 @@ from botocore.exceptions import ClientError
 
 from xoto3.errors import client_error_name
 from xoto3.utils.dt import iso8601strict
+from xoto3.utils.tree_map import SimpleTransform
 from xoto3.dynamodb.types import TableResource
 from xoto3.dynamodb.get import strongly_consistent_get_item
 from xoto3.dynamodb.types import ItemKey, Item, AttrDict
-from xoto3.dynamodb.prewrite import (
-    map_tree,
-    type_dispatched_transform,
-    REQUIRED_TRANSFORMS,
-    RECOMMENDED_TRANSFORMS,
-    SimpleTransform,
-)
 from .core import UpdateItem
-from .diff import build_update_diff, select_attributes_for_set_and_remove
+from .diff import (
+    build_update_diff,
+    select_attributes_for_set_and_remove,
+    _DEFAULT_PREDIFF_TRANSFORM,
+)
 
 
 DEFAULT_MAX_ATTEMPTS_BEFORE_FAILURE = 25
@@ -40,11 +38,6 @@ MAX_TRANSACTION_SLEEP = float(os.environ.get("DYNAMO_VERSIONING_RANDOM_SLEEP_SEC
 logger = getLogger(__name__)
 
 
-_DEFAULT_TRANSFORM = partial(
-    map_tree, type_dispatched_transform({**REQUIRED_TRANSFORMS, **RECOMMENDED_TRANSFORMS})
-)
-
-
 class VersionedUpdateFailure(Exception):
     pass
 
@@ -87,7 +80,7 @@ def versioned_diffed_update_item(
     item_version_key: str = "item_version",
     last_written_key: str = "last_written_at",
     random_sleep_on_lost_race: bool = True,
-    prewrite_transform: ty.Optional[SimpleTransform] = _DEFAULT_TRANSFORM,
+    prewrite_transform: ty.Optional[SimpleTransform] = _DEFAULT_PREDIFF_TRANSFORM,
 ) -> Item:
     """Performs an item read-transform-write loop until there are no intervening writes.
 
@@ -121,10 +114,8 @@ def versioned_diffed_update_item(
         if not updated_item:
             logger.debug("No transformed item was returned; returning original item")
             return item
-        if prewrite_transform:
-            updated_item = prewrite_transform(updated_item)
         assert updated_item is not None
-        item_diff = build_update_diff(item, updated_item)
+        item_diff = build_update_diff(item, updated_item, prediff_transform=prewrite_transform)
         if not item_diff:
             logger.info(
                 "A transformed item was returned but no meaningful difference was found.",
@@ -191,14 +182,14 @@ def versioned_item_expression(
     versioned_item_diffed_update, there is no need to enforce this.
 
     """
-    expr_names = {"#item_version": item_version_key}
-    expr_vals = {":cur_item_version": item_version}
-    item_version_condition = "#item_version = :cur_item_version"
-    first_time_version_condition = "attribute_not_exists(#item_version)"
+    expr_names = {"#itemVersion": item_version_key}
+    expr_vals = {":curItemVersion": item_version}
+    item_version_condition = "#itemVersion = :curItemVersion"
+    first_time_version_condition = "attribute_not_exists(#itemVersion)"
     if id_that_exists:
-        expr_names["#id_that_exists"] = id_that_exists
+        expr_names["#idThatExists"] = id_that_exists
         first_time_version_condition = (
-            f"( {first_time_version_condition} AND attribute_exists(#id_that_exists) )"
+            f"( {first_time_version_condition} AND attribute_exists(#idThatExists) )"
         )
     return dict(
         ExpressionAttributeNames=expr_names,
